import { IKey, IEnv, ICondition, ICustomSteps, ICodeMagicSpecialCase } from '../models/SidiModel';
import { GluegunToolbox } from 'gluegun';
import { SidiConfig } from './SidiConfig';
export declare const workflowConfigUnwantedKeys: string[];
export declare class WorkflowConfig {
    name: string;
    requestedStepsNames: string[];
    stepsNames: string[];
    customSteps: ICustomSteps[];
    triggerPattern: string[];
    androidSigningReferenceName: string[];
    codemagicSpecialCases: ICodeMagicSpecialCase[];
    codemagicPublishingSteps: string[];
    publishingCustomSteps: ICustomSteps[];
    maxDurationTime?: number;
    requiredKeys?: IKey[];
    envs: Array<IEnv>;
    artifacts: string[];
    cicd: string;
    meta: any;
    constructor(cicd: string, workflowConfig?: WorkflowConfig);
    /**
     Set the machine to use on cicd side
     */
    setStackToUse(meta: any): void;
    /**
     Ask to user if he wants to add any custom step to workflow
  
     @param toolbox: GluegunToolbox
     */
    requestCustomSteps(toolbox: GluegunToolbox): Promise<void>;
    /**
     Ask to user if he wants to add any custom step to workflow
  
     @param toolbox: GluegunToolbox
     */
    requestPublishingCustomSteps(toolbox: GluegunToolbox): Promise<void>;
    setNameAndCheckValidity(toolbox: GluegunToolbox, name: string): boolean;
    /**
     * Add step from purposed step
     * Array contains only items purposed in CLI
     *
     * @param stepName
     */
    addRequestedStep(stepName: string): void;
    deleteRequestedStep(stepName: string): void;
    deleteCustomStep(stepName: string): void;
    deletePublishingCustomStep(stepName: string): void;
    setCustomTriggerPattern(pattern: string): void;
    setAndroidSigningKeystoreRef(referenceName: string): void;
    setBuildDurationTime(duration: string): void;
    /**
     * Will add the step to the workflow after check if the step:
     *   - contain any condition
     *   - if condition not set + has choices object, it will be requested to user if he wants use the step
     *   - if condition valid, the step will be added to the workflow
     *
     * @param toolbox: GluegunToolbox
     * @param conditions: conditions to check/request to user to add or not the step
     * @param stepName: step name
     * @param sidiConfig: sidi config object
     * @param isPublishingStep: to add or not on publishing section - codemagic only
     */
    checkConditionsAddStep(toolbox: GluegunToolbox, conditions: ICondition[], stepName: string, sidiConfig: SidiConfig, isPublishingStep?: boolean): Promise<void>;
    /**
     * Will add the step to the workflow
     * to mandatory steps, to place it at the begining of build or not
     * and add required keys to set in future variables
     *
     * @param stepName step's name
     * @param isPublishingStep: to add or not on publishing section - codemagic only
     */
    addStep(stepName: string, isPublishingStep?: boolean): boolean;
    /**
     * Will add the step to a special list to add to the yaml in a special way, to have  valid yaml
     * for CodeMAgic only
     *
     * @param stepSpecialCase step's name
     */
    addSpecialStep(stepSpecialCase: ICodeMagicSpecialCase): boolean;
    /**
      Inject custom steps into stepsNames in the correct place
     */
    setCustomSteps(): void;
    /**
     * Based on mandatoryKeys object, it will inject all required keys linked to the steps to create secret yml
     */
    addRequiredKeys(stepName: string, cicd: string): void;
    /**
     * Based on mandatoryKeys object, it will inject all required keys linked to the steps to create secret yml
     * for Codemagic artifacts only
     */
    addArtifactPaths(stepName: string, cicd: string): void;
    /**
     * Based on mandatoryKeys object, it will inject all required keys linked to the steps to create secret yml
     */
    addEnv(key: string, value: string): void;
    /**
     * Clean steps to refill based on requestedStepsNames
     */
    cleanSteps(): void;
}
